==> xcfa_3.4.1.orig.tar.gz: xcfa-3.4.1/src/prg_init.h <==
 /*
 * file      : prg_init.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __prg_init_h__
#define __prg_init_h__ 1

typedef struct {
	GtkListStore      *Adr_List_Store;
	GtkTreeModel      *Adr_Tree_Model;
	GtkWidget         *Adr_scroll;
	GtkTreeSelection  *Adr_Line_Selected;
	gboolean           Bool_Goto_Page_Options;
	GdkPixbuf         *Pixbuf_Coche;
	GdkPixbuf         *Pixbuf_Selected;
	GdkPixbuf         *Pixbuf_Ok;
	
	
	
	GtkWidget         *button_goto_install;
	GtkWidget         *button_selection_globale;
/*
extern VAR_PRG_INSTALL var_prginstall;
*/


} VAR_PRGEXTERN;

extern VAR_PRGEXTERN var_prgextern;

typedef enum {
	BOOL_NONE = 0,
	BOOL_CDPARANOIA,
	BOOL_CDDA2WAV,
	BOOL_ICEDAX,
	BOOL_FLAC,
	BOOL_LAME,
	BOOL_OGGENC,
	BOOL_MPG321,
	BOOL_PS2PDF,
	BOOL_SOX,
	BOOL_NORMALIZE,
	BOOL_CHECKMP3,
	BOOL_FAAD,
	BOOL_FAAC,
	BOOL_MPLAYER,
	BOOL_W32CODECS,
	BOOL_SHORTEN,
	BOOL_CONVERT,
	BOOL_MPPDEC,
	BOOL_MPPENC,
	BOOL_APE,
	BOOL_WAVPACK,
	BOOL_LSDVD,
	BOOL_VORBISGAIN,
	BOOL_MP3GAIN,
	BOOL_MP3SPLT,
	BOOL_WAVSPLIT,
	BOOL_SHNTOOL,
	BOOL_CUETOOLS,
	BOOL_AACPLUSENC

} TYPE_PROGINIT;

typedef struct {
	gboolean	bool_ape;
	gboolean	bool_mppdec;
	gboolean	bool_mppenc;
	gboolean	bool_cdparanoia;
	gboolean	bool_cdda2wav;
	gboolean	bool_lame;
	gboolean	bool_oggenc;
	gboolean	bool_mpg321;
	gboolean	bool_ps2pdf;
	gboolean	bool_sox;
	gboolean	bool_normalize;
	gboolean	bool_checkmp3;
	gboolean	bool_faad;
	gboolean	bool_faac;
	gboolean	bool_mplayer;
	gboolean	bool_w32codecs;
	gboolean	bool_shorten;
	gboolean	bool_convert;
	gboolean	bool_lsdvd;
	gboolean	bool_vorbisgain;
	gboolean	bool_flac;
	gboolean	bool_mp3gain;
	gboolean	bool_mp3splt;
	gboolean	bool_wavsplit;
	gboolean	bool_wavpack;
	gboolean	bool_shntool;
	gboolean	bool_cuetools;
	gboolean	bool_aacplusenc;
	gchar          *name_checkmp3;
	gchar          *name_normalize;
	gchar          *name_mppenc;
	gchar          *name_mppdec;
	gchar          *name_ape;
	gchar          *name_cdda2wav_icedax;

} PRGINIT;

extern PRGINIT PrgInit;



void       prginit_make_scrolledwindow (GtkWidget *widget);
gboolean   prginit_get_etat (gboolean bool_scan);
void       prginit_set_flag_buttons_install (void);
void       prginit_remove_install (void);
void       prginit_update_glist (void);
gboolean   prginit_set_selected (void);
gboolean   prginit_get_bool_install (void);
gboolean   prginit_is_not_installed (void);
GList     *prginit_get_glist_prog (GList *list);
GList     *prginit_get_glist_install (GList *list);
GList     *prginit_remove_glist_prog (GList *list);
gboolean   prginit_is_selected (void);


#endif

==> xcfa_3.4.9.orig.tar.gz: xcfa-3.4.9/src/prg_init.h <==
 /*
 * file      : prg_init.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __prg_init_h__
#define __prg_init_h__ 1

typedef struct {
	GtkListStore      *Adr_List_Store;
	GtkTreeModel      *Adr_Tree_Model;
	GtkWidget         *Adr_scroll;
	GtkTreeSelection  *Adr_Line_Selected;
	gboolean           Bool_Goto_Page_Options;
	GdkPixbuf         *Pixbuf_Coche;
	GdkPixbuf         *Pixbuf_Selected;
	GdkPixbuf         *Pixbuf_Ok;
	GtkWidget         *button_goto_install;
	GtkWidget         *button_selection_globale;

} VAR_PRGEXTERN;

extern VAR_PRGEXTERN var_prgextern;



typedef enum {
	NMR_aacplusenc = 0,
	NMR_abcde,
	NMR_cdparanoia,
	NMR_checkmp3,
	NMR_imagemagick_convert,
	NMR_cuetools,
	NMR_faac,
	NMR_faad,
	NMR_flac,
	NMR_icedax,
	NMR_lame,
	NMR_lsdvd,
	NMR_mac,
	NMR_mpc123_mppdec,
	NMR_mppenc,
	NMR_mplayer,
	NMR_mp3gain,
	NMR_mpg321,
	NMR_mp3splt,
	NMR_normalize,
	NMR_libnotify_bin,
	NMR_ps2pdf,
	NMR_shorten,
	NMR_shntool,
	NMR_sox,
	NMR_vorbis_tools_oggenc,
	NMR_vorbisgain,
	NMR_wavsplit,
	NMR_wavpack,
	NMR_wXXcodecs,
	
	NMR_MAX_TABLEAU
} TYPE_PROGINIT;



typedef struct {
	gchar		*PackageDebian64;			// PACKAGEDEBIAN_64
	gchar		*PackageDebian32;			// PACKAGEDEBIAN_32
	gchar		*Name1;					// NAME1
	gchar		*Name2;					// NAME2
	gchar		*Name3;					// NAME3
	gboolean	*BoolFound;				// FOUND
	gchar		*DepotDebian64;				// DEPOTDEBIAN_64
	gchar		*DepotDebian32;				// DEPOTDEBIAN_32
	gchar		*PtrName;				// NAME TREE-VIEW : pointeur sur Name1 | Name2 | Name3
	GdkPixbuf	*Pixbuf;				// PIXBUF TREE-VIEW
	gchar		*Description;				// DESCRIPTION TREE-VIEW
} TABLEAU_PRG_EXTERN;

extern TABLEAU_PRG_EXTERN TableauPrgExtern [  ];



typedef struct {
	gboolean	bool_notify_send;
	gboolean	bool_abcde;
	gboolean	bool_ape;
	gboolean	bool_mpc123_mppdec;
	gboolean	bool_mppenc;
	gboolean	bool_cdparanoia;
	gboolean	bool_cdda2wav;
	gboolean	bool_lame;
	gboolean	bool_oggenc;
	gboolean	bool_mpg321;
	gboolean	bool_ps2pdf;
	gboolean	bool_sox;
	gboolean	bool_normalize;
	gboolean	bool_checkmp3;
	gboolean	bool_faad;
	gboolean	bool_faac;
	gboolean	bool_mplayer;
	gboolean	bool_w32codecs;
	gboolean	bool_shorten;
	gboolean	bool_convert;
	gboolean	bool_lsdvd;
	gboolean	bool_vorbisgain;
	gboolean	bool_flac;
	gboolean	bool_mp3gain;
	gboolean	bool_mp3splt;
	gboolean	bool_wavsplit;
	gboolean	bool_wavpack;
	gboolean	bool_shntool;
	gboolean	bool_cuetools;
	gboolean	bool_aacplusenc;

} PRGINIT;

extern PRGINIT PrgInit;



void       prginit_remove_comment (void);
void       prginit_make_scrolledwindow (GtkWidget *widget);
gboolean   prginit_get_etat (void);
void       prginit_update_glist (void);
gboolean   prginit_set_selected (void);
gboolean   prginit_get_bool_install (void);
gboolean   prginit_is_not_installed (void);
gboolean   prginit_is_selected (void);

gchar     *prginit_get_name (TYPE_PROGINIT TypeEnum);
gboolean   prginit_elem_is_ready (TYPE_PROGINIT TypeEnum);
void       prginit_var_default (void);

#endif
